==> stepfunctions-0.8.1-sources.jar: software/amazon/awscdk/services/stepfunctions/cloudformation/StateMachineResource.java <==
package software.amazon.awscdk.services.stepfunctions.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-stepfunctions-statemachine.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.cloudformation.StateMachineResource")
public class StateMachineResource extends software.amazon.awscdk.Resource {
    protected StateMachineResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.cloudformation.StateMachineResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::StepFunctions::StateMachine``.
     * @param parent the ``cdk.Construct`` this ``StateMachineResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``StateMachineResource``
     */
    public StateMachineResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.stepfunctions.cloudformation.StateMachineResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
    /**
     * @cloudformation_attribute Name
     */
    public software.amazon.awscdk.services.stepfunctions.StateMachineName getStateMachineName() {
        return this.jsiiGet("stateMachineName", software.amazon.awscdk.services.stepfunctions.StateMachineName.class);
    }
}

==> stepfunctions-0.19.0-sources.jar: software/amazon/awscdk/services/stepfunctions/cloudformation/StateMachineResource.java <==
package software.amazon.awscdk.services.stepfunctions.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-stepfunctions-statemachine.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.11 (build 44c3b9b)", date = "2018-12-04T12:20:29.255Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.cloudformation.StateMachineResource")
public class StateMachineResource extends software.amazon.awscdk.Resource {
    protected StateMachineResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.stepfunctions.cloudformation.StateMachineResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::StepFunctions::StateMachine``.
     * @param parent the ``cdk.Construct`` this ``StateMachineResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``StateMachineResource``
     */
    public StateMachineResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.stepfunctions.cloudformation.StateMachineResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.stepfunctions.cloudformation.StateMachineResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.stepfunctions.cloudformation.StateMachineResourceProps.class);
    }

    public java.lang.String getStateMachineArn() {
        return this.jsiiGet("stateMachineArn", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Name
     */
    public java.lang.String getStateMachineName() {
        return this.jsiiGet("stateMachineName", java.lang.String.class);
    }
}
